"""

Configs migration



Generation datetime: 2021-03-09 12:52:02.912371

"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "31045054"

DOWN_REVISION = "2932d031"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_LIVENESS_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "real_threshold": {"type": "number", "minimum": 0, "maximum": 1},
                "use_filter": {"type": "integer", "enum": [0, 1]},
                "minimum_detection_size": {"type": "integer"},
                "border_distance": {"type": "integer"},
                "principal_axes": {"type": "integer"},
            },
            "description": "FSDK one shot liveness settings",
            "required": [
                "use_filter",
                "minimum_detection_size",
                "border_distance",
                "principal_axes",
            ],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {"real_threshold": {"type": "number", "minimum": 0, "maximum": 1}},
            "description": "FSDK one shot liveness settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "real_threshold": 0.88,
            "use_filter": 0,
            "minimum_detection_size": 200,
            "border_distance": 10,
            "principal_axes": 25,
        },
        newDefaultValue={"real_threshold": 0.88},
        settingUpgradeFunction=lambda lim: {"real_threshold": lim["real_threshold"]},
        settingDowngradeFunction=lambda lim: {
            "real_threshold": lim["real_threshold"],
            "use_filter": 0,
            "minimum_detection_size": 200,
            "border_distance": 10,
            "principal_axes": 25,
        },
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers"],
        newServices=["luna-api", "luna-handlers"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
