"""
Configs migration

Generation datetime: 2023-10-30 11:00:37.752426
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "5742d47f"
DOWN_REVISION = "b1460ea0"


def downgrade(settings):
    if settings.get("format") == "ecs":
        settings["format"] = "default"
    return settings


PYTHON_SERVICES = [
    "luna-image-store",
    "luna-events",
    "luna-faces",
    "luna-api",
    "luna-admin",
    "luna-sender",
    "luna-tasks",
    "luna-configurator",
    "luna-handlers",
    "luna-python-matcher",
    "luna-matcher-proxy",
    "luna-licenses",
    "luna-backport4",
    "luna-backport3",
    "luna-accounts",
    "luna-remote-sdk",
    "luna-lambda",
    "luna-lambda-unit",
]

limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName=f"{serviceName.replace('-', '_').upper()}_LOGGER",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json"]},
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json", "ecs"]},
            },
            "additionalProperties": False,
        },
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=downgrade,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[serviceName],
        newServices=[serviceName],
    )
    for serviceName in PYTHON_SERVICES
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
