"""
Module contains settings class for luna-configurator
"""

from typing import Optional

from ..settings.classes import DBSetting as _DBSetting
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsConfigurator(BasePythonServiceSettingsClass):
    """
    Settings class for luna-configurator
    Attributes:
        db(DBSetting): database settings
        storageTime(str): storage time setting
    """

    serviceName = "luna-configurator"

    def __init__(self):
        self.db: Optional[_DBSetting] = None
        self.storageTime: Optional[str] = None
        super().__init__()

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.db = _DBSetting(self.serviceName, self["LUNA_CONFIGURATOR_DB"])
        self.storageTime = self["storage_time"]
