"""
Module contains settings class for luna-events
"""

from typing import Optional

from ..settings.classes import DBSetting as _DBSetting, DescriptorEncryption as _DescriptorEncryption
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsEvents(BasePythonServiceSettingsClass):
    """
    Settings class for luna-events
    Attributes:
        db(DBSetting): database settings
        storageTime(str): storage time setting
        defaultFaceDescriptorVersion(int): default face descriptor version setting
        saveEventsTimeout(int): save events timeout
        descriptorEncryption(DescriptorEncryption): descriptors encryption settings
    """

    serviceName = "luna-events"

    def __init__(self):
        super().__init__()

        self.db: Optional[_DBSetting] = None
        self.storageTime: Optional[str] = None
        self.defaultFaceDescriptorVersion: Optional[int] = None
        self.defaultHumanDescriptorVersion: Optional[int] = None
        self.saveEventsTimeout: Optional[int] = None
        self.descriptorEncryption: Optional[_DescriptorEncryption] = None

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.db = _DBSetting(self.serviceName, self["LUNA_EVENTS_DB"])
        self.storageTime = self["storage_time"]
        self.defaultFaceDescriptorVersion = self["default_face_descriptor_version"]
        self.defaultHumanDescriptorVersion = self["default_human_descriptor_version"]
        self.saveEventsTimeout = self["SAVE_EVENTS_TIMEOUT"]
        self.descriptorEncryption = _DescriptorEncryption(self.serviceName, self["DESCRIPTOR_ENCRYPTION"])
