"""
Module contains settings class for luna-image-store
"""

from typing import Optional

from ..settings.classes import ImageStoreStorageSettings as _ImageStoreStorageSettings, S3Settings as _S3Settings
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsImageStore(BasePythonServiceSettingsClass):
    """
    Settings class for luna-image-store
    Attributes:
        storage(ImageStoreStorageSettings): storage settings
        s3(S3Settings): s3 settings
    """

    serviceName = "luna-image-store"

    def __init__(self):
        self.storage: Optional[_ImageStoreStorageSettings] = None
        self.s3: Optional[_S3Settings] = None
        super().__init__()

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.storage = _ImageStoreStorageSettings(self.serviceName, self._settings)

        if self.storage.storageType.lower() == "s3":
            self.s3 = _S3Settings(self.serviceName, self["S3"])
