"""
Module contains settings class for luna-video-agent service
"""

from typing import Optional

from ..settings.classes import (
    AdditionalServicesUsageSetting as _AdditionalServicesUsageSetting,
    AgentVideoSettings as _AgentVideoSettings,
    EstimatorRuntimeSetting as _EstimatorRuntimeSetting,
    ImageStoreAddressSettings as _ImageStoreAddressSettings,
    RuntimeSetting as _RuntimeSetting,
    ServiceAddressSettings as _ServiceAddressSettings,
    ServiceTimeoutsSettings as _ServiceTimeoutsSettings,
)
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsVideoAgent(BasePythonServiceSettingsClass):
    """
    Settings class for luna-video-agent
    """

    serviceName = "luna-video-agent"

    def __init__(self):
        super().__init__()
        self.videoSettings: Optional[_AgentVideoSettings] = None
        self.runtimeSettings: Optional[_RuntimeSetting] = None
        self.videoManagerAddress: Optional[_ServiceAddressSettings] = None
        self.videoManagerTimeouts: Optional[_ServiceTimeoutsSettings] = None
        self.peopleCounterEstimatorSettings: Optional[_EstimatorRuntimeSetting] = None
        self.licensesAddress: Optional[_ServiceAddressSettings] = None
        self.imageOriginStorage: Optional[_ImageStoreAddressSettings] = None
        self.imageOriginStorageTimeouts: Optional[_ServiceTimeoutsSettings] = None
        self.lunaSenderAddress: Optional[_ServiceAddressSettings] = None
        self.lunaSenderTimeouts: Optional[_ServiceTimeoutsSettings] = None
        self.additionalServicesUsage = _AdditionalServicesUsageSetting(
            self.serviceName, self["ADDITIONAL_SERVICES_USAGE"]
        )
        self.externalApiAddress: Optional[_ServiceAddressSettings] = None

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()

        self.videoSettings = _AgentVideoSettings(
            self.serviceName, "LUNA_VIDEO_AGENT_VIDEO_SETTINGS", self["LUNA_VIDEO_AGENT_VIDEO_SETTINGS"]
        )

        self.runtimeSettings = _RuntimeSetting(
            self.serviceName,
            "LUNA_VIDEO_AGENT_RUNTIME_SETTINGS",
            self["LUNA_VIDEO_AGENT_RUNTIME_SETTINGS"],
        )

        self.videoManagerAddress = _ServiceAddressSettings(
            self.serviceName, "LUNA_VIDEO_MANAGER_ADDRESS", self["LUNA_VIDEO_MANAGER_ADDRESS"]
        )
        self.videoManagerTimeouts = _ServiceTimeoutsSettings(
            self.serviceName,
            "LUNA_VIDEO_MANAGER_TIMEOUTS",
            self["LUNA_VIDEO_MANAGER_TIMEOUTS"],
        )
        self.peopleCounterEstimatorSettings = _EstimatorRuntimeSetting(
            self.serviceName,
            "LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS",
            self["LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS"]["runtime_settings"],
        )
        self.licensesAddress = _ServiceAddressSettings(
            self.serviceName, "LUNA_LICENSES_ADDRESS", self["LUNA_LICENSES_ADDRESS"]
        )
        self.imageOriginStorage = _ImageStoreAddressSettings(
            self.serviceName,
            "LUNA_IMAGE_STORE_IMAGES_ADDRESS",
            self["LUNA_IMAGE_STORE_IMAGES_ADDRESS"],
        )
        self.imageOriginStorageTimeouts = _ServiceTimeoutsSettings(
            self.serviceName,
            "LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
            self["LUNA_IMAGE_STORE_IMAGES_TIMEOUTS"],
        )
        self.lunaSenderAddress = _ServiceAddressSettings(
            self.serviceName,
            "LUNA_SENDER_ADDRESS",
            self["LUNA_SENDER_ADDRESS"],
        )
        self.lunaSenderTimeouts = _ServiceTimeoutsSettings(
            self.serviceName,
            "LUNA_SENDER_TIMEOUTS",
            self["LUNA_SENDER_TIMEOUTS"],
        )
        self.additionalServicesUsage = _AdditionalServicesUsageSetting(
            self.serviceName, self["ADDITIONAL_SERVICES_USAGE"]
        )
        self.externalApiAddress = _ServiceAddressSettings(
            self.serviceName,
            "EXTERNAL_LUNA_API_ADDRESS",
            self["EXTERNAL_LUNA_API_ADDRESS"],
        )

        return self
