"""
Module contains settings class for luna-video-manager
"""

from typing import Optional

from ..settings.classes import DBSetting as _DBSetting
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsVideoManager(BasePythonServiceSettingsClass):
    """
    Settings class for luna-video-manager
    """

    serviceName = "luna-video-manager"

    def __init__(self):
        super().__init__()
        self.db: Optional[_DBSetting] = None
        self.storageTime: Optional[str] = None
        self.streamStatusObsoletingPeriod: Optional[float] = None
        self.streamStatusObsoletingInterval: Optional[float] = None
        self.agentStatusObsoletingPeriod: Optional[float] = None
        self.agentStatusObsoletingInterval: Optional[float] = None
        self.streamsAgentSearchInterval: Optional[float] = None
        self.autoRestarterInterval: Optional[float] = None

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.db = _DBSetting(self.serviceName, self["LUNA_VIDEO_MANAGER_DB"])
        self.storageTime = self["storage_time"]
        self.streamStatusObsoletingPeriod = self["LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_PERIOD"]
        self.streamStatusObsoletingInterval = self["LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_INTERVAL"]
        self.agentStatusObsoletingPeriod = self["LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_PERIOD"]
        self.agentStatusObsoletingInterval = self["LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_INTERVAL"]
        self.streamsAgentSearchInterval = self["LUNA_VIDEO_MANAGER_STREAMS_AGENT_SEARCH_INTERVAL"]
        self.autoRestarterInterval = self["LUNA_VIDEO_MANAGER_STREAMS_AUTORESTARTER_INTERVAL"]
