"""
Module contains request class for handlers lambda
"""

from typing import final

from luna_lambda_tools.private.request import BaseHandlersRequest
from luna_lambda_tools.public.clients import Clients
from luna_lambda_tools.public.clients.events import Events
from luna_lambda_tools.public.clients.faces import Faces
from luna_lambda_tools.public.clients.lis import LIS
from luna_lambda_tools.public.clients.lpm import LPM
from luna_lambda_tools.public.clients.lrs import LRS
from luna_lambda_tools.public.clients.sender import Sender
from luna_lambda_tools.public.handlers.schemas import EventSourceSchema


@final
class HandlersLambdaRequest(BaseHandlersRequest):
    """Handlers lambda request"""

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.clients: Clients = Clients(
            faces=Faces(**self._getFacesClientKwargs()),
            events=Events(**self._getEventsClientKwargs()),
            matcher=LPM(**self._getLPMClientKwargs()),
            faceSamplesStore=LIS(**self._getFacesSamplesClientKwargs()),
            bodySamplesStore=LIS(**self._getBodySamplesClientKwargs()),
            imageOriginStore=LIS(**self._getImageOriginClientKwargs()),
            sdk=LRS(**self._getLRSClientKwargs()),
            sender=Sender(**self._getSenderClientKwargs()),
        )

    @property
    def data(self) -> EventSourceSchema:
        """Get events sources from request"""
        return super().getRequestData(EventSourceSchema)
